summaryrefslogtreecommitdiffstats
diff options
context:
space:
mode:
authorTimothy Pearson <kb9vqf@pearsoncomputing.net>2011-12-16 09:57:41 -0600
committerTimothy Pearson <kb9vqf@pearsoncomputing.net>2011-12-16 09:57:41 -0600
commitef9e895fa20a6118dacbd997a1ed7486e14b8ec6 (patch)
tree1a4f00ea9a3840933a87b3447a923222e53d092c
parent4614cf2e7bce250f5b9cdef409cb89330d60bb1d (diff)
downloadsoundkonverter-ef9e895f.tar.gz
soundkonverter-ef9e895f.zip
Revert "Rename a number of old tq methods that are no longer tq specific"
This reverts commit 4614cf2e7bce250f5b9cdef409cb89330d60bb1d.
-rwxr-xr-xsrc/cddb.cpp6
-rwxr-xr-xsrc/cdopener.cpp36
-rwxr-xr-xsrc/combobutton.cpp8
-rwxr-xr-xsrc/configbackendspage.cpp16
-rwxr-xr-xsrc/configdialog.cpp2
-rwxr-xr-xsrc/configenvironmentpage.cpp2
-rwxr-xr-xsrc/configgeneralpage.cpp2
-rwxr-xr-xsrc/configpluginspage.cpp8
-rwxr-xr-xsrc/convert.cpp20
-rwxr-xr-xsrc/cuesheeteditor.cpp2
-rwxr-xr-xsrc/dirdialog.cpp2
-rwxr-xr-xsrc/filelist.cpp62
-rwxr-xr-xsrc/filelist.h4
-rwxr-xr-xsrc/logger.cpp4
-rwxr-xr-xsrc/logger.h2
-rwxr-xr-xsrc/logviewer.cpp12
-rwxr-xr-xsrc/logviewer.h2
-rw-r--r--src/metadata/m4a/mp4file.h2
-rw-r--r--src/metadata/m4a/mp4mvhdbox.cpp2
-rw-r--r--src/metadata/m4a/mp4mvhdbox.h2
-rw-r--r--src/metadata/trueaudio/ttafile.h2
-rw-r--r--src/metadata/wavpack/wvfile.h2
-rwxr-xr-xsrc/options.cpp2
-rwxr-xr-xsrc/optionsdetailed.cpp8
-rwxr-xr-xsrc/optionseditor.cpp44
-rwxr-xr-xsrc/optionsrequester.cpp2
-rwxr-xr-xsrc/optionssimple.cpp4
-rwxr-xr-xsrc/outputdirectory.cpp2
-rwxr-xr-xsrc/progressindicator.cpp2
-rwxr-xr-xsrc/replaygainfilelist.cpp104
-rwxr-xr-xsrc/replaygainfilelist.h4
-rwxr-xr-xsrc/replaygainscanner.cpp2
-rwxr-xr-xsrc/soundkonverter.cpp4
33 files changed, 189 insertions, 189 deletions
diff --git a/src/cddb.cpp b/src/cddb.cpp
index bf66bbb..c1ef793 100755
--- a/src/cddb.cpp
+++ b/src/cddb.cpp
@@ -30,7 +30,7 @@
#include <errno.h>
#include <unistd.h>
#include <tqdir.h>
-#include <textstream.h>
+#include <tqtextstream.h>
#include <tqregexp.h>
//#include <tqapp.h>
#include <tqstring.h>
@@ -377,7 +377,7 @@ CDDB::parse_read_resp(TQTextStream *stream, TQTextStream *write_stream)
for (int i = 0; i < m_tracks; i++)
{
if (m_names[i].isEmpty())
- m_names[i] += i18n("Track %1").arg(i);
+ m_names[i] += i18n("Track %1").tqarg(i);
//m_names[i].replace(TQRegExp("/"), "%2f");
si = m_names[i].find(" - ");
if (si < 0)
@@ -423,7 +423,7 @@ CDDB::searchLocal(unsigned int id, TQFile *ret_file)
{
TQDir dir;
TQString filename;
- filename = TQString("%1").arg(id, 0, 16).rightJustify(8, '0');
+ filename = TQString("%1").tqarg(id, 0, 16).rightJustify(8, '0');
TQStringList::ConstIterator it;
for (it = cddb_dirs.begin(); it != cddb_dirs.end(); ++it)
{
diff --git a/src/combobutton.cpp b/src/combobutton.cpp
index 4723f39..9b71947 100755
--- a/src/combobutton.cpp
+++ b/src/combobutton.cpp
@@ -1,7 +1,7 @@
#include "combobutton.h"
-#include <layout.h>
+#include <tqlayout.h>
#include <tqstring.h>
#include <tqpixmap.h>
#include <tqstyle.h>
@@ -43,11 +43,11 @@ void ComboButton::balanceSize()
int width;
if( m_sizeMode == Max )
- width = m_box->sizeHint().width()-17;
+ width = m_box->tqsizeHint().width()-17;
else
- width = m_button->sizeHint().width();
+ width = m_button->tqsizeHint().width();
- int height = ( m_box->sizeHint().height() > m_button->sizeHint().height() ) ? m_box->sizeHint().height() : m_button->sizeHint().height();
+ int height = ( m_box->tqsizeHint().height() > m_button->tqsizeHint().height() ) ? m_box->tqsizeHint().height() : m_button->tqsizeHint().height();
m_box->setFixedSize( width+17, height+m_increaseHeight );
m_button->setFixedSize( width, height+m_increaseHeight );
diff --git a/src/configbackendspage.cpp b/src/configbackendspage.cpp
index 226aae3..7a5f16a 100755
--- a/src/configbackendspage.cpp
+++ b/src/configbackendspage.cpp
@@ -5,7 +5,7 @@
#include "ripperpluginloader.h"
#include "config.h"
-#include <layout.h>
+#include <tqlayout.h>
#include <tqlabel.h>
#include <tqgroupbox.h>
#include <tqtooltip.h>
@@ -52,8 +52,8 @@ ConfigBackendsPage::ConfigBackendsPage( Config* _config, TQMap<TQString, TQStrin
legendBox->setStretchFactor( lLegendLabel, 1 );
TQGroupBox* ripperGroup = new TQGroupBox( 1, Qt::Vertical, box, "ripperGroup" );
- ripperGroup->layout()->setSpacing( 6 );
- ripperGroup->layout()->setMargin( 6 );
+ ripperGroup->tqlayout()->setSpacing( 6 );
+ ripperGroup->tqlayout()->setMargin( 6 );
TQLabel* lRipper = new TQLabel( i18n("CD Ripper")+":", ripperGroup, "lRipper" );
cRipper = new KComboBox( ripperGroup, "cRipper" );
connect( cRipper, TQT_SIGNAL(activated(int)),
@@ -252,10 +252,10 @@ void ConfigBackendsPage::rebuild()
options.group = new TQGroupBox( title, box, options.format );
options.group->setColumnLayout( 0, Qt::Vertical );
- options.group->layout()->setSpacing( 6 );
- options.group->layout()->setMargin( 6 );
+ options.group->tqlayout()->setSpacing( 6 );
+ options.group->tqlayout()->setMargin( 6 );
options.group->show();
- options.grid = new TQGridLayout( options.group->layout() );
+ options.grid = new TQGridLayout( options.group->tqlayout() );
options.lEncoder = new TQLabel( i18n("Encoder")+":", options.group, options.format );
options.lEncoder->show();
@@ -271,7 +271,7 @@ void ConfigBackendsPage::rebuild()
options.grid->addWidget( options.cEncoder, 0, 1 );
options.lStrength = new TQLabel( i18n("Strength")+":", options.group, options.format );
- options.lStrength->setAlignment( TQt::AlignRight | TQt::AlignVCenter );
+ options.lStrength->tqsetAlignment( TQt::AlignRight | TQt::AlignVCenter );
options.lStrength->show();
options.grid->addWidget( options.lStrength, 0, 2 );
options.sStrength = new TQSlider( Qt::Horizontal, options.group, options.format );
@@ -296,7 +296,7 @@ void ConfigBackendsPage::rebuild()
this, TQT_SLOT(cfgChanged())
);
options.lStrengthDisplay = new TQLabel( "", options.group, options.format );
- options.lStrengthDisplay->setAlignment( TQt::AlignRight | TQt::AlignVCenter );
+ options.lStrengthDisplay->tqsetAlignment( TQt::AlignRight | TQt::AlignVCenter );
options.lStrengthDisplay->setEnabled( false );
options.grid->addWidget( options.lStrengthDisplay, 1, 3 );
diff --git a/src/configdialog.cpp b/src/configdialog.cpp
index cfdd9ee..f53844f 100755
--- a/src/configdialog.cpp
+++ b/src/configdialog.cpp
@@ -18,7 +18,7 @@
#include "backend_plugins.h"
#include "replaygain_plugins.h"
-#include <layout.h>
+#include <tqlayout.h>
*/
//#include <kconfig.h>
#include <kiconloader.h>
diff --git a/src/configenvironmentpage.cpp b/src/configenvironmentpage.cpp
index 3b559b8..3c4b776 100755
--- a/src/configenvironmentpage.cpp
+++ b/src/configenvironmentpage.cpp
@@ -12,7 +12,7 @@
#include <kfiledialog.h>
#include <kstandarddirs.h>
-#include <layout.h>
+#include <tqlayout.h>
#include <tqlabel.h>
#include <tqtooltip.h>
#include <tqmap.h>
diff --git a/src/configgeneralpage.cpp b/src/configgeneralpage.cpp
index fe1ddb1..b389f81 100755
--- a/src/configgeneralpage.cpp
+++ b/src/configgeneralpage.cpp
@@ -11,7 +11,7 @@
#include <kpushbutton.h>
#include <kfiledialog.h>
-#include <layout.h>
+#include <tqlayout.h>
#include <tqlabel.h>
#include <tqcheckbox.h>
#include <tqtooltip.h>
diff --git a/src/configpluginspage.cpp b/src/configpluginspage.cpp
index 0db6368..5502ea6 100755
--- a/src/configpluginspage.cpp
+++ b/src/configpluginspage.cpp
@@ -6,7 +6,7 @@
#include "ripperpluginloader.h"
#include <tqlabel.h>
-#include <layout.h>
+#include <tqlayout.h>
#include <tqfile.h>
#include <tqfileinfo.h>
#include <tqcheckbox.h>
@@ -207,19 +207,19 @@ void ConfigPluginsPage::refreshPlugins()
TQValueList<ConvertPlugin*> converters = config->allConverters();
for( TQValueList<ConvertPlugin*>::Iterator it = converters.begin(); it != converters.end(); ++it ) {
lPlugins->insertItem( (*it)->info.name + " v. " + TQString::number((*it)->info.version) );
- //lPlugins->insertItem( i18n("%1, Version: %2").arg((*it)->info.name).arg((*it)->info.version) );
+ //lPlugins->insertItem( i18n("%1, Version: %2").tqarg((*it)->info.name).tqarg((*it)->info.version) );
}
TQValueList<ReplayGainPlugin*> replaygains = config->allReplayGains();
for( TQValueList<ReplayGainPlugin*>::Iterator it = replaygains.begin(); it != replaygains.end(); ++it ) {
lPlugins->insertItem( (*it)->info.name + " v. " + TQString::number((*it)->info.version) );
- //lPlugins->insertItem( i18n("%1, Version: %2").arg((*it)->info.name).arg((*it)->info.version) );
+ //lPlugins->insertItem( i18n("%1, Version: %2").tqarg((*it)->info.name).tqarg((*it)->info.version) );
}
TQValueList<RipperPlugin*> rippers = config->allRippers();
for( TQValueList<RipperPlugin*>::Iterator it = rippers.begin(); it != rippers.end(); ++it ) {
lPlugins->insertItem( (*it)->info.name + " v. " + TQString::number((*it)->info.version) );
- //lPlugins->insertItem( i18n("%1, Version: %2").arg((*it)->info.name).arg((*it)->info.version) );
+ //lPlugins->insertItem( i18n("%1, Version: %2").tqarg((*it)->info.name).tqarg((*it)->info.version) );
}
}
diff --git a/src/convert.cpp b/src/convert.cpp
index 5b9b2b5..9f5000a 100755
--- a/src/convert.cpp
+++ b/src/convert.cpp
@@ -161,12 +161,12 @@ void Convert::rip( ConvertItem* item )
TQString wavFile;
TQString args = job->device;
if(!args.isEmpty())
- args = TQString("?device=%1").arg(args);
+ args = TQString("?device=%1").tqarg(args);
args = args+"&fileNameTemplate=Track %{number}";
if(job->track < 10)
- wavFile = TQString("audiocd:/Wav/Track 0%1.wav%2").arg(job->track).arg(args);
+ wavFile = TQString("audiocd:/Wav/Track 0%1.wav%2").tqarg(job->track).tqarg(args);
else
- wavFile = TQString("audiocd:/Wav/Track %1.wav%2").arg(job->track).arg(args);
+ wavFile = TQString("audiocd:/Wav/Track %1.wav%2").tqarg(job->track).tqarg(args);
*/
RipperPlugin* plugin = config->getCurrentRipper();
@@ -888,7 +888,7 @@ void Convert::moveFinished( KIO::Job* job )
}
else if( (*item)->state == ConvertItem::put ) {
if( job->error() != 0 ) {
- logger->log( (*item)->logID, i18n("Could not write to file: `%1'").arg(OutputDirectory::calcPath((*item)->fileListItem,config)) );
+ logger->log( (*item)->logID, i18n("Could not write to file: `%1'").tqarg(OutputDirectory::calcPath((*item)->fileListItem,config)) );
emit uncountTime( (*item)->getTime );
emit uncountTime( (*item)->getCorrectionTime );
emit uncountTime( (*item)->ripTime );
@@ -1201,7 +1201,7 @@ void Convert::processExit( KProcess* proc )
}
if( (*item)->state == ConvertItem::put ) {
if( proc->signalled() ) {
- logger->log( (*item)->logID, i18n("Could not write to file: `%1'").arg(OutputDirectory::calcPath((*item)->fileListItem,config)) );
+ logger->log( (*item)->logID, i18n("Could not write to file: `%1'").tqarg(OutputDirectory::calcPath((*item)->fileListItem,config)) );
emit uncountTime( (*item)->getTime );
emit uncountTime( (*item)->getCorrectionTime );
emit uncountTime( (*item)->ripTime );
@@ -1213,7 +1213,7 @@ void Convert::processExit( KProcess* proc )
return;
}
if( !proc->normalExit() ) {
- logger->log( (*item)->logID, i18n("Could not write to file: `%1'").arg(OutputDirectory::calcPath((*item)->fileListItem,config)) );
+ logger->log( (*item)->logID, i18n("Could not write to file: `%1'").tqarg(OutputDirectory::calcPath((*item)->fileListItem,config)) );
emit uncountTime( (*item)->getTime );
emit uncountTime( (*item)->getCorrectionTime );
emit uncountTime( (*item)->ripTime );
@@ -1289,14 +1289,14 @@ void Convert::processExit( KProcess* proc )
void Convert::add( FileListItem* item )
{
- logger->log( 1000, i18n("Adding new item to conversion list: `%1'").arg(item->options.filePathName) );
+ logger->log( 1000, i18n("Adding new item to conversion list: `%1'").tqarg(item->options.filePathName) );
// append the item to the item list and store the iterator
TQValueList<ConvertItem*>::Iterator newItem = items.append( new ConvertItem( item ) );
// register at the logger
(*newItem)->logID = logger->registerProcess( item->options.filePathName );
- logger->log( 1000, " " + i18n("Got log ID: %1").arg((*newItem)->logID) );
+ logger->log( 1000, " " + i18n("Got log ID: %1").tqarg((*newItem)->logID) );
logger->log( (*newItem)->logID, "Mime Type: " + (*newItem)->fileListItem->mimeType );
if( (*newItem)->fileListItem->tags ) logger->log( (*newItem)->logID, i18n("Tags successfully read") );
@@ -1465,14 +1465,14 @@ void Convert::remove( ConvertItem* item, int state )
//emit uncountTime( item->getTime + item->getCorrectionTime + item->ripTime +
// item->decodeTime + item->encodeTime + item->replaygainTime );
- logger->log( item->logID, i18n("Removing file from conversion list. Exit code %1").arg(state) );
+ logger->log( item->logID, i18n("Removing file from conversion list. Exit code %1").tqarg(state) );
if( item->fileListItem->notify != "" ) {
TQString command = item->fileListItem->notify;
command.replace( "%u", item->fileListItem->url );
command.replace( "%i", item->fileListItem->options.filePathName.replace(" ","%20") );
command.replace( "%o", item->outputFilePathName.replace(" ","%20") );
- logger->log( item->logID, " "+i18n("Executing command: \"%1\"").arg(command) );
+ logger->log( item->logID, " "+i18n("Executing command: \"%1\"").tqarg(command) );
notify.clearArguments();
TQString paramSplinter;
// FIXME split correct (strings with spaces are splited by mistake)
diff --git a/src/cuesheeteditor.cpp b/src/cuesheeteditor.cpp
index 73fecf8..812e916 100755
--- a/src/cuesheeteditor.cpp
+++ b/src/cuesheeteditor.cpp
@@ -1,7 +1,7 @@
#include "cuesheeteditor.h"
-#include <layout.h>
+#include <tqlayout.h>
#include <tqstring.h>
#include <klocale.h>
diff --git a/src/dirdialog.cpp b/src/dirdialog.cpp
index fa1bbfd..b76d148 100755
--- a/src/dirdialog.cpp
+++ b/src/dirdialog.cpp
@@ -2,7 +2,7 @@
#include "dirdialog.h"
#include "config.h"
-#include <layout.h>
+#include <tqlayout.h>
#include <tqlabel.h>
#include <tqdir.h>
#include <tqcheckbox.h>
diff --git a/src/filelist.cpp b/src/filelist.cpp
index ecb9e68..de6e46e 100755
--- a/src/filelist.cpp
+++ b/src/filelist.cpp
@@ -21,7 +21,7 @@
#include <kurldrag.h>
#include <kapplication.h>
-#include <layout.h>
+#include <tqlayout.h>
#include <tqfileinfo.h>
#include <tqsimplerichtext.h>
#include <tqpainter.h>
@@ -59,7 +59,7 @@ FileListItem::FileListItem( KListView* parent )
FileListItem::~FileListItem()
{}
-void FileListItem::paintCell( TQPainter *p, const TQColorGroup &cg, int column, int width, int alignment )
+void FileListItem::paintCell( TQPainter *p, const TQColorGroup &cg, int column, int width, int tqalignment )
{
// NOTE speed up this function
// NOTE calculate the red color
@@ -72,14 +72,14 @@ void FileListItem::paintCell( TQPainter *p, const TQColorGroup &cg, int column,
int margin = listView()->itemMargin();
int w = width - 2*margin;
int h = height();
- TQRect textRect = p->boundingRect( margin, 0, w, h, alignment, text(column) );
+ TQRect textRect = p->boundingRect( margin, 0, w, h, tqalignment, text(column) );
if( textRect.width() > w ) {
- alignment = TQt::AlignRight | TQt::SingleLine;
+ tqalignment = TQt::AlignRight | TQt::SingleLine;
}
/*if ( textRect.width() <= w ) {
- p->drawText( margin, 0, w, h, alignment | TQt::SingleLine | TQt::ExpandTabs, text(column), -1 );
+ p->drawText( margin, 0, w, h, tqalignment | TQt::SingleLine | TQt::ExpandTabs, text(column), -1 );
}
else {
textRect = p->boundingRect( margin, 0, w, h, TQt::AlignLeft, "... " );
@@ -90,21 +90,21 @@ void FileListItem::paintCell( TQPainter *p, const TQColorGroup &cg, int column,
if( isSelected() && converting ) {
_cg.setColor( TQColorGroup::Highlight, TQColor( 215, 62, 62 ) );
- TQListViewItem::paintCell( p, _cg, column, width, alignment );
+ TQListViewItem::paintCell( p, _cg, column, width, tqalignment );
return;
}
else if( converting && column != listView()->sortColumn() ) {
_cg.setColor( TQColorGroup::Base, TQColor( 255, 234, 234 ) );
- TQListViewItem::paintCell( p, _cg, column, width, alignment );
+ TQListViewItem::paintCell( p, _cg, column, width, tqalignment );
return;
}
else if( converting && column == listView()->sortColumn() ) {
_cg.setColor( TQColorGroup::Base, TQColor( 247, 227, 227 ) );
- TQListViewItem::paintCell( p, _cg, column, width, alignment );
+ TQListViewItem::paintCell( p, _cg, column, width, tqalignment );
return;
}
- KListViewItem::paintCell( p, _cg, column, width, alignment );
+ KListViewItem::paintCell( p, _cg, column, width, tqalignment );
}
/*void FileListItem::updateOutputCell()
@@ -152,11 +152,11 @@ FileList::FileList( CDManager* _cdManager, TagEngine* _tagEngine, Config* _confi
grid->setRowStretch( 2, 1 );
grid->setColStretch( 0, 1 );
grid->setColStretch( 2, 1 );
- pScanStatus = new KProgress( this, "pScanStatus" );
- pScanStatus->setMinimumHeight( pScanStatus->height() );
- pScanStatus->setFormat( "%v / %m" );
- pScanStatus->hide();
- grid->addWidget( pScanStatus, 1, 1 );
+ pScantqStatus = new KProgress( this, "pScanStatus" );
+ pScantqStatus->setMinimumHeight( pScantqStatus->height() );
+ pScantqStatus->setFormat( "%v / %m" );
+ pScantqStatus->hide();
+ grid->addWidget( pScantqStatus, 1, 1 );
grid->setColStretch( 1, 2 );
contextMenu = new KPopupMenu( this );
@@ -226,9 +226,9 @@ void FileList::viewportPaintEvent( TQPaintEvent* e )
const uint w = bubble->width() + 20;
const uint h = bubble->height() + 20;
- p.setBrush( colorGroup().background() );
+ p.setBrush( tqcolorGroup().background() );
p.drawRoundRect( 15, 15, w, h, (8*200)/w, (8*200)/h );
- bubble->draw( &p, 20, 20, TQRect(), colorGroup() );
+ bubble->draw( &p, 20, 20, TQRect(), tqcolorGroup() );
}
}
@@ -379,15 +379,15 @@ int FileList::listDir( const TQString& directory, TQStringList filter, bool recu
else if( !fileInfo.isDir() || !recursive ) { // NOTE checking for isFile may not work with all file names
// NOTE filter feature
for( TQStringList::Iterator jt = filter.begin(); jt != filter.end(); ++jt ) {
- if( (*it).endsWith("."+(*jt),false) ) {
+ if( (*it).tqendsWith("."+(*jt),false) ) {
count++;
- pScanStatus->setTotalSteps( count );
+ pScantqStatus->setTotalSteps( count );
break;
}
}
if( filter.first() == "" ) {
count++;
- pScanStatus->setTotalSteps( count );
+ pScantqStatus->setTotalSteps( count );
}
}
}
@@ -398,17 +398,17 @@ int FileList::listDir( const TQString& directory, TQStringList filter, bool recu
else if( !fileInfo.isDir() || !recursive ) { // NOTE checking for isFile may not work with all file names
// NOTE filter feature
for( TQStringList::Iterator jt = filter.begin(); jt != filter.end(); ++jt ) {
- if( (*it).endsWith("."+(*jt),false) ) {
+ if( (*it).tqendsWith("."+(*jt),false) ) {
addFiles( KURL::encode_string(directory + "/" + *it) );
count++;
- pScanStatus->setProgress( count );
+ pScantqStatus->setProgress( count );
break;
}
}
if( filter.first() == "" ) {
addFiles( KURL::encode_string(directory + "/" + *it) );
count++;
- pScanStatus->setProgress( count );
+ pScantqStatus->setProgress( count );
}
}
}
@@ -567,15 +567,15 @@ void FileList::addFiles( TQStringList fileList, FileListItem* after, bool enable
void FileList::addDir( const TQString& directory, const TQStringList& filter, bool recursive )
{
- pScanStatus->setProgress( 0 );
- pScanStatus->setTotalSteps( 0 );
- pScanStatus->show(); // show the status while scanning the directories
+ pScantqStatus->setProgress( 0 );
+ pScantqStatus->setTotalSteps( 0 );
+ pScantqStatus->show(); // show the status while scanning the directories
kapp->processEvents();
int count = listDir( directory, filter, recursive, true );
listDir( directory, filter, recursive );
- pScanStatus->hide(); // hide the status bar, when the scan is done
+ pScantqStatus->hide(); // hide the status bar, when the scan is done
}
void FileList::addTracks( const TQString& device, TQValueList<int> trackList )
@@ -587,7 +587,7 @@ void FileList::addTracks( const TQString& device, TQValueList<int> trackList )
// if( newItem->options.outputOptions.mode != OutputDirectory::Specify ) newItem->options.outputOptions.mode = OutputDirectory::MetaData;
newItem->notify = notify;
newItem->track = (*it);
- newItem->fileName = i18n("Audio CD (%1)").arg(device) + ": " + i18n("Track") + TQString().sprintf(" %02i",newItem->track);
+ newItem->fileName = i18n("Audio CD (%1)").tqarg(device) + ": " + i18n("Track") + TQString().sprintf(" %02i",newItem->track);
newItem->mimeType = "application/x-cda";
newItem->fileFormat = "cda";
newItem->local = true;
@@ -602,7 +602,7 @@ void FileList::addTracks( const TQString& device, TQValueList<int> trackList )
// logger->log( 1000, " " + i18n("Tags successfully read") );
newItem->time = newItem->tags->length;
newItem->options.filePathName = TQDir::homeDirPath() + "/" + TQString().sprintf("%02i - ",newItem->track) + newItem->tags->title + "." + newItem->fileFormat;
- newItem->fileName = i18n("Audio CD (%1)").arg(device) + ": " + TQString().sprintf("%02i - ",newItem->track) + newItem->tags->title;
+ newItem->fileName = i18n("Audio CD (%1)").tqarg(device) + ": " + TQString().sprintf("%02i - ",newItem->track) + newItem->tags->title;
}
updateItem( newItem );
emit increaseTime( newItem->time );
@@ -612,13 +612,13 @@ void FileList::addTracks( const TQString& device, TQValueList<int> trackList )
void FileList::addDisc( const TQString& device )
{
-// logger->log( 1000, i18n("Adding full audio CD (%1)").arg(device) );
+// logger->log( 1000, i18n("Adding full audio CD (%1)").tqarg(device) );
FileListItem* newItem = new FileListItem( this, lastItem() );
newItem->options = options->getCurrentOptions();
// if( newItem->options.outputOptions.mode != OutputDirectory::Specify ) newItem->options.outputOptions.mode = OutputDirectory::MetaData;
newItem->notify = notify;
newItem->track = 0;
- newItem->fileName = i18n("Full audio CD (%1)").arg(device);
+ newItem->fileName = i18n("Full audio CD (%1)").tqarg(device);
newItem->mimeType = "application/x-cda";
newItem->fileFormat = "cda";
newItem->local = true;
@@ -633,7 +633,7 @@ void FileList::addDisc( const TQString& device )
// logger->log( 1000, " " + i18n("Tags successfully read") );
newItem->time = newItem->tags->length;
newItem->options.filePathName = TQDir::homeDirPath() + newItem->tags->title + "." + newItem->fileFormat;
- newItem->fileName = i18n("Full audio CD (%1)").arg(device) + ": " + newItem->tags->title;
+ newItem->fileName = i18n("Full audio CD (%1)").tqarg(device) + ": " + newItem->tags->title;
}
updateItem( newItem );
emit increaseTime( newItem->time );
diff --git a/src/filelist.h b/src/filelist.h
index 272dd0c..e34dcf2 100755
--- a/src/filelist.h
+++ b/src/filelist.h
@@ -50,7 +50,7 @@ public:
*/
virtual ~FileListItem();
- virtual void paintCell( TQPainter* p, const TQColorGroup& cg, int column, int width, int alignment );
+ virtual void paintCell( TQPainter* p, const TQColorGroup& cg, int column, int width, int tqalignment );
//void updateOutputCell();
//void updateOptionsCell();
@@ -118,7 +118,7 @@ private:
int listDir( const TQString& directory, TQStringList filter, bool recursive = true, bool fast = false, int count = 0 );
/** A progressbar, that is shown, when a directory is added recursive */
- KProgress* pScanStatus;
+ KProgress* pScantqStatus;
void convertNextItem();
diff --git a/src/logger.cpp b/src/logger.cpp
index 5566c07..27438b7 100755
--- a/src/logger.cpp
+++ b/src/logger.cpp
@@ -22,7 +22,7 @@ Logger::Logger()
(*item)->id = 1000;
(*item)->completed = true;
(*item)->state = 1;
- (*item)->file.setName( locateLocal("data",TQString("soundkonverter/log/%1.log").arg((*item)->id)) );
+ (*item)->file.setName( locateLocal("data",TQString("soundkonverter/log/%1.log").tqarg((*item)->id)) );
// TODO error handling
(*item)->file.open( IO_WriteOnly );
(*item)->textStream.setDevice( TQT_TQIODEVICE(&((*item)->file)) );
@@ -52,7 +52,7 @@ int Logger::registerProcess( const TQString& filename )
(*item)->filename = filename;
(*item)->id = getNewID();
(*item)->completed = false;
- (*item)->file.setName( locateLocal("data",TQString("soundkonverter/log/%1.log").arg((*item)->id)) );
+ (*item)->file.setName( locateLocal("data",TQString("soundkonverter/log/%1.log").tqarg((*item)->id)) );
// TODO error handling
(*item)->file.open( IO_WriteOnly );
(*item)->textStream.setDevice( TQT_TQIODEVICE(&((*item)->file)) );
diff --git a/src/logger.h b/src/logger.h
index 3c67354..53fbbc2 100755
--- a/src/logger.h
+++ b/src/logger.h
@@ -7,7 +7,7 @@
#include <tqstringlist.h>
#include <tqdatetime.h>
#include <tqfile.h>
-#include <textstream.h>
+#include <tqtextstream.h>
/**
diff --git a/src/logviewer.cpp b/src/logviewer.cpp
index ba92f0a..5017a02 100755
--- a/src/logviewer.cpp
+++ b/src/logviewer.cpp
@@ -2,7 +2,7 @@
#include "logviewer.h"
#include "logger.h"
-#include <layout.h>
+#include <tqlayout.h>
#include <tqstring.h>
#include <tqheader.h>
#include <tqcolor.h>
@@ -31,7 +31,7 @@ LogViewerItem::LogViewerItem( LogViewerItem* parent, LogViewerItem* after, TQStr
LogViewerItem::~LogViewerItem()
{}
-void LogViewerItem::paintCell( TQPainter *p, const TQColorGroup &cg, int column, int width, int alignment )
+void LogViewerItem::paintCell( TQPainter *p, const TQColorGroup &cg, int column, int width, int tqalignment )
{
// NOTE calculate the red color
@@ -40,21 +40,21 @@ void LogViewerItem::paintCell( TQPainter *p, const TQColorGroup &cg, int column,
if( isSelected() && converting ) {
_cg.setColor( TQColorGroup::Highlight, TQColor( 215, 62, 62 ) );
- TQListViewItem::paintCell( p, _cg, column, width, alignment );
+ TQListViewItem::paintCell( p, _cg, column, width, tqalignment );
return;
}
else if( converting && column != listView()->sortColumn() ) {
_cg.setColor( TQColorGroup::Base, TQColor( 255, 234, 234 ) );
- TQListViewItem::paintCell( p, _cg, column, width, alignment );
+ TQListViewItem::paintCell( p, _cg, column, width, tqalignment );
return;
}
else if( converting && column == listView()->sortColumn() ) {
_cg.setColor( TQColorGroup::Base, TQColor( 247, 227, 227 ) );
- TQListViewItem::paintCell( p, _cg, column, width, alignment );
+ TQListViewItem::paintCell( p, _cg, column, width, tqalignment );
return;
}
- KListViewItem::paintCell( p, _cg, column, width, alignment );
+ KListViewItem::paintCell( p, _cg, column, width, tqalignment );
}
diff --git a/src/logviewer.h b/src/logviewer.h
index 50da656..d58c51f 100755
--- a/src/logviewer.h
+++ b/src/logviewer.h
@@ -39,7 +39,7 @@ public:
*/
virtual ~LogViewerItem();
- virtual void paintCell( TQPainter* p, const TQColorGroup& cg, int column, int width, int alignment );
+ virtual void paintCell( TQPainter* p, const TQColorGroup& cg, int column, int width, int tqalignment );
LogViewerItem* nextSibling() const { return static_cast<LogViewerItem*>( KListViewItem::nextSibling() ); }
LogViewerItem* firstChild() const { return static_cast<LogViewerItem*>( KListViewItem::firstChild() ); }
diff --git a/src/metadata/m4a/mp4file.h b/src/metadata/m4a/mp4file.h
index 9e40dbc..c1da43d 100644
--- a/src/metadata/m4a/mp4file.h
+++ b/src/metadata/m4a/mp4file.h
@@ -104,7 +104,7 @@ namespace TagLib {
/*!
* This will remove all tags.
*
- * \note This will also invalidate pointers to the tags
+ * \note This will also tqinvalidate pointers to the tags
* as their memory will be freed.
* \note In order to make the removal permanent save() still needs to be called
*/
diff --git a/src/metadata/m4a/mp4mvhdbox.cpp b/src/metadata/m4a/mp4mvhdbox.cpp
index 36053e4..894f7f8 100644
--- a/src/metadata/m4a/mp4mvhdbox.cpp
+++ b/src/metadata/m4a/mp4mvhdbox.cpp
@@ -39,7 +39,7 @@ public:
TagLib::uint timescale;
//! duration of presentation
TagLib::ulonglong duration;
- //! playout speed
+ //! ptqlayout speed
TagLib::uint rate;
//! volume for entire presentation
TagLib::uint volume;
diff --git a/src/metadata/m4a/mp4mvhdbox.h b/src/metadata/m4a/mp4mvhdbox.h
index b133485..31e3d74 100644
--- a/src/metadata/m4a/mp4mvhdbox.h
+++ b/src/metadata/m4a/mp4mvhdbox.h
@@ -44,7 +44,7 @@ namespace TagLib
uint timescale() const;
//! function to get the presentation duration in the mp4 file
ulonglong duration() const;
- //! function to get the rate (playout speed) - typically 1.0;
+ //! function to get the rate (ptqlayout speed) - typically 1.0;
uint rate() const;
//! function to get volume level for presentation - typically 1.0;
uint volume() const;
diff --git a/src/metadata/trueaudio/ttafile.h b/src/metadata/trueaudio/ttafile.h
index 2cb0785..3a97a9e 100644
--- a/src/metadata/trueaudio/ttafile.h
+++ b/src/metadata/trueaudio/ttafile.h
@@ -154,7 +154,7 @@ namespace TagLib {
* This will remove the tags that match the OR-ed together TagTypes from the
* file. By default it removes all tags.
*
- * \note This will also invalidate pointers to the tags
+ * \note This will also tqinvalidate pointers to the tags
* as their memory will be freed.
* \note In order to make the removal permanent save() still needs to be called
*/
diff --git a/src/metadata/wavpack/wvfile.h b/src/metadata/wavpack/wvfile.h
index 6c57f6d..18f2316 100644
--- a/src/metadata/wavpack/wvfile.h
+++ b/src/metadata/wavpack/wvfile.h
@@ -136,7 +136,7 @@ namespace TagLib {
* This will remove the tags that match the OR-ed together TagTypes from the
* file. By default it removes all tags.
*
- * \note This will also invalidate pointers to the tags
+ * \note This will also tqinvalidate pointers to the tags
* as their memory will be freed.
* \note In order to make the removal permanent save() still needs to be called
*/
diff --git a/src/options.cpp b/src/options.cpp
index f329a0f..4f9e881 100755
--- a/src/options.cpp
+++ b/src/options.cpp
@@ -4,7 +4,7 @@
#include "optionsdetailed.h"
#include "config.h"
-#include <layout.h>
+#include <tqlayout.h>
#include <tqtooltip.h>
#include <tqfile.h>
#include <tqcolor.h>
diff --git a/src/optionsdetailed.cpp b/src/optionsdetailed.cpp
index 9f19685..7072474 100755
--- a/src/optionsdetailed.cpp
+++ b/src/optionsdetailed.cpp
@@ -3,7 +3,7 @@
#include "convertpluginloader.h"
#include "config.h"
-#include <layout.h>
+#include <tqlayout.h>
#include <tqlabel.h>
#include <tqcheckbox.h>
#include <tqtooltip.h>
@@ -53,7 +53,7 @@ OptionsDetailed::OptionsDetailed( Config* _config, TQWidget *parent, const char
this, TQT_SLOT(somethingChanged())
);
cQualityMode = new KComboBox( normalOptions, "cQualityMode" );
- cQualityMode->setFixedSize( cQualityMode->sizeHint() );
+ cQualityMode->setFixedSize( cQualityMode->tqsizeHint() );
normalTopBox->addWidget( cQualityMode, 0, TQt::AlignVCenter );
connect( cQualityMode, TQT_SIGNAL(activated(int)),
this, TQT_SLOT(qualityModeChanged())
@@ -686,9 +686,9 @@ void OptionsDetailed::qualityChanged()
}
}
- TQToolTip::add( iQuality, i18n("This is a relative quality between 0 and 100.\nThe higher this number the higher is the quality.\nsoundKonverter will convert it into the file format's quality format.\nSee the \"What's this?\" for more informations.\n\nCurrent parameter: \"%1\"").arg(quality) );
+ TQToolTip::add( iQuality, i18n("This is a relative quality between 0 and 100.\nThe higher this number the higher is the quality.\nsoundKonverter will convert it into the file format's quality format.\nSee the \"What's this?\" for more informations.\n\nCurrent parameter: \"%1\"").tqarg(quality) );
// TQToolTip toolTip( iQuality );
-// toolTip.tip( i18n("Current parameter: \"%1\"").arg(quality) );
+// toolTip.tip( i18n("Current parameter: \"%1\"").tqarg(quality) );
}
}
diff --git a/src/optionseditor.cpp b/src/optionseditor.cpp
index 262bd8d..740f8dd 100755
--- a/src/optionseditor.cpp
+++ b/src/optionseditor.cpp
@@ -6,7 +6,7 @@
#include "conversionoptions.h"
#include "outputdirectory.h"
-#include <layout.h>
+#include <tqlayout.h>
#include <tqstring.h>
#include <tqlabel.h>
#include <tqdatetime.h>
@@ -65,10 +65,10 @@ OptionsEditor::OptionsEditor( TagEngine* _tagEngine, Config* _config, FileList*
lEditOptions = new TQLabel( "", conversionOptions, "lEditOptions" );
conversionOptionsGridLayout->addWidget( lEditOptions, 2, 0 );
- lEditOptions->setAlignment( TQt::AlignHCenter );
+ lEditOptions->tqsetAlignment( TQt::AlignHCenter );
lEditOptions->hide();
pEditOptions = new KPushButton( i18n("Edit conversion options"), conversionOptions, "pEditOptions" );
- pEditOptions->setFixedWidth( pEditOptions->sizeHint().width() );
+ pEditOptions->setFixedWidth( pEditOptions->tqsizeHint().width() );
conversionOptionsGridLayout->addWidget( pEditOptions, 3, 0, TQt::AlignHCenter );
pEditOptions->hide();
connect( pEditOptions, TQT_SIGNAL(clicked()),
@@ -81,7 +81,7 @@ OptionsEditor::OptionsEditor( TagEngine* _tagEngine, Config* _config, FileList*
TQGridLayout* tagsGridLayout = new TQGridLayout( tags, 1, 1, 0, 6, "tagsGridLayout" );
// add the inputs
- // add a horizontal box layout for the title and track number
+ // add a horizontal box tqlayout for the title and track number
TQHBoxLayout *titleBox = new TQHBoxLayout( -1, "titleBox" );
tagsGridLayout->addLayout( titleBox, 0, 1 );
// and fill it up
@@ -94,7 +94,7 @@ OptionsEditor::OptionsEditor( TagEngine* _tagEngine, Config* _config, FileList*
);
pTitleEdit = new KPushButton( " ", tags, "pTitleEdit" );
pTitleEdit->setPixmap( iconLoader->loadIcon("kwrite",KIcon::Small) );
- pTitleEdit->setFixedSize( lTitle->sizeHint().height(), lTitle->sizeHint().height() );
+ pTitleEdit->setFixedSize( lTitle->tqsizeHint().height(), lTitle->tqsizeHint().height() );
pTitleEdit->hide();
titleBox->addWidget( pTitleEdit );
connect( pTitleEdit, TQT_SIGNAL(clicked()),
@@ -109,14 +109,14 @@ OptionsEditor::OptionsEditor( TagEngine* _tagEngine, Config* _config, FileList*
);
pNumberEdit = new KPushButton( " ", tags, "pNumberEdit" );
pNumberEdit->setPixmap( iconLoader->loadIcon("kwrite",KIcon::Small) );
- pNumberEdit->setFixedSize( iNumber->sizeHint().height(), iNumber->sizeHint().height() );
+ pNumberEdit->setFixedSize( iNumber->tqsizeHint().height(), iNumber->tqsizeHint().height() );
pNumberEdit->hide();
titleBox->addWidget( pNumberEdit );
connect( pNumberEdit, TQT_SIGNAL(clicked()),
this, TQT_SLOT(editNumberClicked())
);
- // add a horizontal box layout for the artist and the composer
+ // add a horizontal box tqlayout for the artist and the composer
TQHBoxLayout *artistBox = new TQHBoxLayout( -1, "artistBox" );
tagsGridLayout->addLayout( artistBox, 1, 1 );
// and fill it up
@@ -129,7 +129,7 @@ OptionsEditor::OptionsEditor( TagEngine* _tagEngine, Config* _config, FileList*
);
pArtistEdit = new KPushButton( " ", tags, "pArtistEdit" );
pArtistEdit->setPixmap( iconLoader->loadIcon("kwrite",KIcon::Small) );
- pArtistEdit->setFixedSize( lArtist->sizeHint().height(), lArtist->sizeHint().height() );
+ pArtistEdit->setFixedSize( lArtist->tqsizeHint().height(), lArtist->tqsizeHint().height() );
pArtistEdit->hide();
artistBox->addWidget( pArtistEdit );
connect( pArtistEdit, TQT_SIGNAL(clicked()),
@@ -144,14 +144,14 @@ OptionsEditor::OptionsEditor( TagEngine* _tagEngine, Config* _config, FileList*
);
pComposerEdit = new KPushButton( " ", tags, "pComposerEdit" );
pComposerEdit->setPixmap( iconLoader->loadIcon("kwrite",KIcon::Small) );
- pComposerEdit->setFixedSize( lComposer->sizeHint().height(), lComposer->sizeHint().height() );
+ pComposerEdit->setFixedSize( lComposer->tqsizeHint().height(), lComposer->tqsizeHint().height() );
pComposerEdit->hide();
artistBox->addWidget( pComposerEdit );
connect( pComposerEdit, TQT_SIGNAL(clicked()),
this, TQT_SLOT(editComposerClicked())
);
- // add a horizontal box layout for the album
+ // add a horizontal box tqlayout for the album
TQHBoxLayout *albumBox = new TQHBoxLayout( -1, "albumBox" );
tagsGridLayout->addLayout( albumBox, 2, 1 );
// and fill it up
@@ -164,14 +164,14 @@ OptionsEditor::OptionsEditor( TagEngine* _tagEngine, Config* _config, FileList*
);
pAlbumEdit = new KPushButton( " ", tags, "pAlbumEdit" );
pAlbumEdit->setPixmap( iconLoader->loadIcon("kwrite",KIcon::Small) );
- pAlbumEdit->setFixedSize( lAlbum->sizeHint().height(), lAlbum->sizeHint().height() );
+ pAlbumEdit->setFixedSize( lAlbum->tqsizeHint().height(), lAlbum->tqsizeHint().height() );
pAlbumEdit->hide();
albumBox->addWidget( pAlbumEdit );
connect( pAlbumEdit, TQT_SIGNAL(clicked()),
this, TQT_SLOT(editAlbumClicked())
);
- // add a horizontal box layout for the disc number, year and genre
+ // add a horizontal box tqlayout for the disc number, year and genre
TQHBoxLayout *albumdataBox = new TQHBoxLayout( -1, "albumdataBox" );
tagsGridLayout->addLayout( albumdataBox, 3, 1 );
// and fill it up
@@ -184,7 +184,7 @@ OptionsEditor::OptionsEditor( TagEngine* _tagEngine, Config* _config, FileList*
);
pDiscEdit = new KPushButton( " ", tags, "pDiscEdit" );
pDiscEdit->setPixmap( iconLoader->loadIcon("kwrite",KIcon::Small) );
- pDiscEdit->setFixedSize( iDisc->sizeHint().height(), iDisc->sizeHint().height() );
+ pDiscEdit->setFixedSize( iDisc->tqsizeHint().height(), iDisc->tqsizeHint().height() );
pDiscEdit->hide();
albumdataBox->addWidget( pDiscEdit );
connect( pDiscEdit, TQT_SIGNAL(clicked()),
@@ -193,14 +193,14 @@ OptionsEditor::OptionsEditor( TagEngine* _tagEngine, Config* _config, FileList*
albumdataBox->addStretch();
lYearLabel = new TQLabel( i18n("Year:"), tags, "lYearLabel" );
albumdataBox->addWidget( lYearLabel );
- iYear = new KIntSpinBox( 0, 99999, 1, TQDate::currentDate().year(), 10, tags, "iYear" );
+ iYear = new KIntSpinBox( 0, 99999, 1, TQDate::tqcurrentDate().year(), 10, tags, "iYear" );
albumdataBox->addWidget( iYear );
connect( iYear, TQT_SIGNAL(valueChanged(int)),
this, TQT_SLOT(yearChanged(int))
);
pYearEdit = new KPushButton( " ", tags, "pYearEdit" );
pYearEdit->setPixmap( iconLoader->loadIcon("kwrite",KIcon::Small) );
- pYearEdit->setFixedSize( iYear->sizeHint().height(), iYear->sizeHint().height() );
+ pYearEdit->setFixedSize( iYear->tqsizeHint().height(), iYear->tqsizeHint().height() );
pYearEdit->hide();
albumdataBox->addWidget( pYearEdit );
connect( pYearEdit, TQT_SIGNAL(clicked()),
@@ -221,14 +221,14 @@ OptionsEditor::OptionsEditor( TagEngine* _tagEngine, Config* _config, FileList*
);
pGenreEdit = new KPushButton( " ", tags, "pGenreEdit" );
pGenreEdit->setPixmap( iconLoader->loadIcon("kwrite",KIcon::Small) );
- pGenreEdit->setFixedSize( cGenre->sizeHint().height(), cGenre->sizeHint().height() );
+ pGenreEdit->setFixedSize( cGenre->tqsizeHint().height(), cGenre->tqsizeHint().height() );
pGenreEdit->hide();
albumdataBox->addWidget( pGenreEdit );
connect( pGenreEdit, TQT_SIGNAL(clicked()),
this, TQT_SLOT(editGenreClicked())
);
- // add a horizontal box layout for the comment
+ // add a horizontal box tqlayout for the comment
TQHBoxLayout *commentBox = new TQHBoxLayout( -1, "commentBox" );
tagsGridLayout->addLayout( commentBox, 4, 1 );
// and fill it up
@@ -241,7 +241,7 @@ OptionsEditor::OptionsEditor( TagEngine* _tagEngine, Config* _config, FileList*
);
pCommentEdit = new KPushButton( " ", tags, "pCommentEdit" );
pCommentEdit->setPixmap( iconLoader->loadIcon("kwrite",KIcon::Small) );
- pCommentEdit->setFixedSize( lTitle->sizeHint().height(), lTitle->sizeHint().height() );
+ pCommentEdit->setFixedSize( lTitle->tqsizeHint().height(), lTitle->tqsizeHint().height() );
pCommentEdit->hide();
commentBox->addWidget( pCommentEdit );
connect( pCommentEdit, TQT_SIGNAL(clicked()),
@@ -251,10 +251,10 @@ OptionsEditor::OptionsEditor( TagEngine* _tagEngine, Config* _config, FileList*
lEditTags = new TQLabel( "", tags, "lEditTags" );
tagsGridLayout->addWidget( lEditTags, 5, 1 );
- lEditTags->setAlignment( TQt::AlignHCenter );
+ lEditTags->tqsetAlignment( TQt::AlignHCenter );
lEditTags->hide();
pEditTags = new KPushButton( i18n("Edit tags"), tags, "pEditTags" );
- pEditTags->setFixedWidth( pEditTags->sizeHint().width() );
+ pEditTags->setFixedWidth( pEditTags->tqsizeHint().width() );
tagsGridLayout->addWidget( pEditTags, 6, 1, TQt::AlignHCenter );
pEditTags->hide();
connect( pEditTags, TQT_SIGNAL(clicked()),
@@ -384,7 +384,7 @@ void OptionsEditor::itemsSelected( TQValueList<FileListItem*> items )
}
}
else {
- setCaption( i18n("%1 Files").arg(items.count()) );
+ setCaption( i18n("%1 Files").tqarg(items.count()) );
TQValueList<FileListItem*>::Iterator it = items.begin();
ConversionOptions cOptions = (*it)->options;
TQString title = ( (*it)->tags == 0 ) ? "" : (*it)->tags->title;
@@ -446,7 +446,7 @@ void OptionsEditor::itemsSelected( TQValueList<FileListItem*> items )
}
if( year != (*it)->tags->year && iYear->isEnabled() ) {
iYear->setEnabled( false );
- iYear->setValue( TQDate::currentDate().year() );
+ iYear->setValue( TQDate::tqcurrentDate().year() );
pYearEdit->show();
}
if( genre != (*it)->tags->genre && cGenre->isEnabled() ) {
diff --git a/src/optionsrequester.cpp b/src/optionsrequester.cpp
index 154905a..ec547ee 100755
--- a/src/optionsrequester.cpp
+++ b/src/optionsrequester.cpp
@@ -3,7 +3,7 @@
#include "options.h"
#include "config.h"
-#include <layout.h>
+#include <tqlayout.h>
#include <tqlabel.h>
#include <tqstringlist.h>
diff --git a/src/optionssimple.cpp b/src/optionssimple.cpp
index cf8c73e..cfc4a55 100755
--- a/src/optionssimple.cpp
+++ b/src/optionssimple.cpp
@@ -4,7 +4,7 @@
#include "convertpluginloader.h"
#include "optionsdetailed.h"
-#include <layout.h>
+#include <tqlayout.h>
#include <tqlabel.h>
#include <tqstring.h>
#include <tqtooltip.h>
@@ -202,7 +202,7 @@ void OptionsSimple::profileInfo()
void OptionsSimple::profileRemove()
{
int ret = KMessageBox::questionYesNo( this,
- i18n("Do you really want to remove the profile: %1").arg(cProfile->currentText()),
+ i18n("Do you really want to remove the profile: %1").tqarg(cProfile->currentText()),
i18n("Remove profile?") );
if( ret != KMessageBox::Yes ) return;
diff --git a/src/outputdirectory.cpp b/src/outputdirectory.cpp
index e9d7fe0..8c5479e 100755
--- a/src/outputdirectory.cpp
+++ b/src/outputdirectory.cpp
@@ -5,7 +5,7 @@
#include "tagengine.h"
#include "config.h"
-#include <layout.h>
+#include <tqlayout.h>
#include <tqtooltip.h>
#include <tqdir.h>
#include <tqfileinfo.h>
diff --git a/src/progressindicator.cpp b/src/progressindicator.cpp
index ebc69a6..e2255a3 100755
--- a/src/progressindicator.cpp
+++ b/src/progressindicator.cpp
@@ -1,7 +1,7 @@
#include "progressindicator.h"
-#include <layout.h>
+#include <tqlayout.h>
#include <tqlabel.h>
#include <tqprogressbar.h>
#include <tqtooltip.h>
diff --git a/src/replaygainfilelist.cpp b/src/replaygainfilelist.cpp
index 0ddfb55..c260d17 100755
--- a/src/replaygainfilelist.cpp
+++ b/src/replaygainfilelist.cpp
@@ -11,7 +11,7 @@
#include <tqsimplerichtext.h>
#include <tqapplication.h>
#include <tqheader.h>
-#include <layout.h>
+#include <tqlayout.h>
#include <tqtimer.h>
#include <klocale.h>
@@ -63,7 +63,7 @@ ReplayGainFileListItem::ReplayGainFileListItem( ReplayGainFileListItem* parent )
ReplayGainFileListItem::~ReplayGainFileListItem()
{}
-void ReplayGainFileListItem::paintCell( TQPainter *p, const TQColorGroup &cg, int column, int width, int alignment )
+void ReplayGainFileListItem::paintCell( TQPainter *p, const TQColorGroup &cg, int column, int width, int tqalignment )
{
// NOTE speed up this function
// NOTE calculate the red color
@@ -76,46 +76,46 @@ void ReplayGainFileListItem::paintCell( TQPainter *p, const TQColorGroup &cg, in
int margin = listView()->itemMargin();
int w = width - 2*margin;
int h = height();
- TQRect textRect = p->boundingRect( margin, 0, w, h, alignment, text(column) );
+ TQRect textRect = p->boundingRect( margin, 0, w, h, tqalignment, text(column) );
if( textRect.width() > w ) {
- alignment = TQt::AlignRight | TQt::SingleLine;
+ tqalignment = TQt::AlignRight | TQt::SingleLine;
}
}
if( isSelected() && addingReplayGain ) {
_cg.setColor( TQColorGroup::Highlight, TQColor( 215, 62, 62 ) );
- TQListViewItem::paintCell( p, _cg, column, width, alignment );
+ TQListViewItem::paintCell( p, _cg, column, width, tqalignment );
return;
}
else if( addingReplayGain && column != listView()->sortColumn() ) {
_cg.setColor( TQColorGroup::Base, TQColor( 255, 234, 234 ) );
- TQListViewItem::paintCell( p, _cg, column, width, alignment );
+ TQListViewItem::paintCell( p, _cg, column, width, tqalignment );
return;
}
else if( addingReplayGain && column == listView()->sortColumn() ) {
_cg.setColor( TQColorGroup::Base, TQColor( 247, 227, 227 ) );
- TQListViewItem::paintCell( p, _cg, column, width, alignment );
+ TQListViewItem::paintCell( p, _cg, column, width, tqalignment );
return;
}
if( isSelected() && queued ) {
_cg.setColor( TQColorGroup::Highlight, TQColor( 230, 232, 100 ) );
- TQListViewItem::paintCell( p, _cg, column, width, alignment );
+ TQListViewItem::paintCell( p, _cg, column, width, tqalignment );
return;
}
else if( queued && column != listView()->sortColumn() ) {
_cg.setColor( TQColorGroup::Base, TQColor( 255, 255, 190 ) );
- TQListViewItem::paintCell( p, _cg, column, width, alignment );
+ TQListViewItem::paintCell( p, _cg, column, width, tqalignment );
return;
}
else if( queued && column == listView()->sortColumn() ) {
_cg.setColor( TQColorGroup::Base, TQColor( 255, 243, 168 ) );
- TQListViewItem::paintCell( p, _cg, column, width, alignment );
+ TQListViewItem::paintCell( p, _cg, column, width, tqalignment );
return;
}
- KListViewItem::paintCell( p, _cg, column, width, alignment );
+ KListViewItem::paintCell( p, _cg, column, width, tqalignment );
}
void ReplayGainFileListItem::setType( Type type )
@@ -195,11 +195,11 @@ ReplayGainFileList::ReplayGainFileList( TagEngine* _tagEngine, Config* _config,
grid->setRowStretch( 2, 1 );
grid->setColStretch( 0, 1 );
grid->setColStretch( 2, 1 );
- pScanStatus = new KProgress( this, "pScanStatus" );
- pScanStatus->setMinimumHeight( pScanStatus->height() );
- pScanStatus->setFormat( "%v / %m" );
- pScanStatus->hide();
- grid->addWidget( pScanStatus, 1, 1 );
+ pScantqStatus = new KProgress( this, "pScanStatus" );
+ pScantqStatus->setMinimumHeight( pScantqStatus->height() );
+ pScantqStatus->setFormat( "%v / %m" );
+ pScantqStatus->hide();
+ grid->addWidget( pScantqStatus, 1, 1 );
grid->setColStretch( 1, 2 );
contextMenu = new KPopupMenu( this );
@@ -279,9 +279,9 @@ void ReplayGainFileList::viewportPaintEvent( TQPaintEvent* e )
const uint w = bubble->width() + 20;
const uint h = bubble->height() + 20;
- p.setBrush( colorGroup().background() );
+ p.setBrush( tqcolorGroup().background() );
p.drawRoundRect( 15, 15, w, h, (8*200)/w, (8*200)/h );
- bubble->draw( &p, 20, 20, TQRect(), colorGroup() );
+ bubble->draw( &p, 20, 20, TQRect(), tqcolorGroup() );
}
}
@@ -512,15 +512,15 @@ int ReplayGainFileList::listDir( const TQString& directory, TQStringList filter,
else if( !fileInfo.isDir() || !recursive ) { // NOTE checking for isFile may not work with all file names
// NOTE filter feature
for( TQStringList::Iterator jt = filter.begin(); jt != filter.end(); ++jt ) {
- if( (*it).endsWith("."+(*jt),false) ) {
+ if( (*it).tqendsWith("."+(*jt),false) ) {
count++;
- pScanStatus->setTotalSteps( count );
+ pScantqStatus->setTotalSteps( count );
break;
}
}
if( filter.first() == "" ) {
count++;
- pScanStatus->setTotalSteps( count );
+ pScantqStatus->setTotalSteps( count );
}
}
}
@@ -531,17 +531,17 @@ int ReplayGainFileList::listDir( const TQString& directory, TQStringList filter,
else if( !fileInfo.isDir() || !recursive ) { // NOTE checking for isFile may not work with all file names
// NOTE filter feature
for( TQStringList::Iterator jt = filter.begin(); jt != filter.end(); ++jt ) {
- if( (*it).endsWith("."+(*jt),false) ) {
+ if( (*it).tqendsWith("."+(*jt),false) ) {
addFile( KURL::encode_string(directory + "/" + *it) );
count++;
- pScanStatus->setProgress( count );
+ pScantqStatus->setProgress( count );
break;
}
}
if( filter.first() == "" ) {
addFile( KURL::encode_string(directory + "/" + *it) );
count++;
- pScanStatus->setProgress( count );
+ pScantqStatus->setProgress( count );
}
}
}
@@ -742,15 +742,15 @@ void ReplayGainFileList::addFile( const TQString& file )
void ReplayGainFileList::addDir( const TQString& directory, const TQStringList& filter, bool recursive )
{
- pScanStatus->setProgress( 0 );
- pScanStatus->setTotalSteps( 0 );
- pScanStatus->show(); // show the status while scanning the directories
+ pScantqStatus->setProgress( 0 );
+ pScantqStatus->setTotalSteps( 0 );
+ pScantqStatus->show(); // show the status while scanning the directories
kapp->processEvents();
int count = listDir( directory, filter, recursive, true );
listDir( directory, filter, recursive );
- pScanStatus->hide(); // hide the status bar, when the scan is done
+ pScantqStatus->hide(); // hide the status bar, when the scan is done
}
void ReplayGainFileList::openAlbums()
@@ -836,18 +836,18 @@ void ReplayGainFileList::calcSelectedItemsGain()
if( item->type() == ReplayGainFileListItem::File ) {
if( item->isSelected() ) {
item->queued = true;
- item->repaint();
+ item->tqrepaint();
item->mode = ReplayGainFileListItem::force;
}
}
else {
if( item->isSelected() ) {
item->queued = true;
- item->repaint();
+ item->tqrepaint();
item->mode = ReplayGainFileListItem::force;
for( ReplayGainFileListItem* sub_item = item->firstChild(); sub_item != 0; sub_item = sub_item->nextSibling() ) {
sub_item->queued = true;
- sub_item->repaint();
+ sub_item->tqrepaint();
sub_item->mode = ReplayGainFileListItem::force;
}
}
@@ -855,11 +855,11 @@ void ReplayGainFileList::calcSelectedItemsGain()
for( ReplayGainFileListItem* sub_item = item->firstChild(); sub_item != 0; sub_item = sub_item->nextSibling() ) {
if( sub_item->isSelected() ) {
item->queued = true;
- item->repaint();
+ item->tqrepaint();
item->mode = ReplayGainFileListItem::force;
for( ReplayGainFileListItem* sub_item2 = item->firstChild(); sub_item2 != 0; sub_item2 = sub_item2->nextSibling() ) {
sub_item2->queued = true;
- sub_item2->repaint();
+ sub_item2->tqrepaint();
sub_item2->mode = ReplayGainFileListItem::force;
}
break;
@@ -878,18 +878,18 @@ void ReplayGainFileList::removeSelectedItemsGain()
if( item->type() == ReplayGainFileListItem::File ) {
if( item->isSelected() && !item->addingReplayGain ) {
item->queued = true;
- item->repaint();
+ item->tqrepaint();
item->mode = ReplayGainFileListItem::remove;
}
}
else {
if( item->isSelected() && !item->addingReplayGain ) {
item->queued = true;
- item->repaint();
+ item->tqrepaint();
item->mode = ReplayGainFileListItem::remove;
for( ReplayGainFileListItem* sub_item = item->firstChild(); sub_item != 0; sub_item = sub_item->nextSibling() ) {
sub_item->queued = true;
- sub_item->repaint();
+ sub_item->tqrepaint();
sub_item->mode = ReplayGainFileListItem::remove;
}
}
@@ -897,7 +897,7 @@ void ReplayGainFileList::removeSelectedItemsGain()
for( ReplayGainFileListItem* sub_item = item->firstChild(); sub_item != 0; sub_item = sub_item->nextSibling() ) {
if( sub_item->isSelected() && !sub_item->addingReplayGain ) {
sub_item->queued = true;
- sub_item->repaint();
+ sub_item->tqrepaint();
sub_item->mode = ReplayGainFileListItem::remove;
}
}
@@ -926,12 +926,12 @@ void ReplayGainFileList::calcReplayGain( ReplayGainFileListItem* item )
if( item->type() == ReplayGainFileListItem::Album ) {
item->queued = false;
item->addingReplayGain = true;
- item->repaint();
+ item->tqrepaint();
for( ReplayGainFileListItem* sub_item = item->firstChild(); sub_item != 0; sub_item = sub_item->nextSibling() ) {
if( sub_item->queued && sub_item->mode & ReplayGainFileListItem::force ) force = true; // NOTE can this be replaced by checking item?
sub_item->queued = false;
sub_item->addingReplayGain = true;
- sub_item->repaint();
+ sub_item->tqrepaint();
fileList += sub_item->filePathName;
files++;
@@ -953,10 +953,10 @@ void ReplayGainFileList::calcReplayGain( ReplayGainFileListItem* item )
else {
logger->processCompleted( logID, 0 );
item->addingReplayGain = false;
- item->repaint();
+ item->tqrepaint();
for( ReplayGainFileListItem* sub_item = item->firstChild(); sub_item != 0; sub_item = sub_item->nextSibling() ) {
sub_item->addingReplayGain = false;
- sub_item->repaint();
+ sub_item->tqrepaint();
}
processNextFile();
}
@@ -966,7 +966,7 @@ void ReplayGainFileList::calcReplayGain( ReplayGainFileListItem* item )
item->queued = false;
item->addingReplayGain = true;
- item->repaint();
+ item->tqrepaint();
files = 1;
timeCount = item->time;
@@ -989,13 +989,13 @@ void ReplayGainFileList::removeReplayGain( ReplayGainFileListItem* item )
if( item->type() == ReplayGainFileListItem::File ) {
item->queued = false;
item->addingReplayGain = true;
- item->repaint();
+ item->tqrepaint();
timeCount = item->time;
replayGain->apply( item->filePathName, item->mimeType, process, logID, ReplayGain::remove );
}
else {
item->queued = false;
- item->repaint();
+ item->tqrepaint();
processNextFile();
}
}
@@ -1201,43 +1201,43 @@ void ReplayGainFileList::processExit( KProcess* proc )
if( item->addingReplayGain ) {
processedTime += item->time;
item->addingReplayGain = false;
- item->repaint();
+ item->tqrepaint();
item->updateReplayGainCells( tagEngine->readTags(KURL::decode_string(item->filePathName)) );
}
if( item->queued && proc->signalled() ) {
item->queued = false;
- item->repaint();
+ item->tqrepaint();
}
}
else {
if( item->addingReplayGain ) {
item->addingReplayGain = false;
- item->repaint();
+ item->tqrepaint();
for( ReplayGainFileListItem* sub_item = item->firstChild(); sub_item != 0; sub_item = sub_item->nextSibling() ) {
processedTime += sub_item->time;
sub_item->addingReplayGain = false;
- sub_item->repaint();
+ sub_item->tqrepaint();
sub_item->updateReplayGainCells( tagEngine->readTags(KURL::decode_string(sub_item->filePathName)) );
}
}
if( item->queued && proc->signalled() ) {
item->queued = false;
- item->repaint();
+ item->tqrepaint();
for( ReplayGainFileListItem* sub_item = item->firstChild(); sub_item != 0; sub_item = sub_item->nextSibling() ) {
sub_item->queued = false;
- sub_item->repaint();
+ sub_item->tqrepaint();
}
}
for( ReplayGainFileListItem* sub_item = item->firstChild(); sub_item != 0; sub_item = sub_item->nextSibling() ) {
if( sub_item->addingReplayGain ) {
processedTime += sub_item->time;
sub_item->addingReplayGain = false;
- sub_item->repaint();
+ sub_item->tqrepaint();
sub_item->updateReplayGainCells( tagEngine->readTags(KURL::decode_string(sub_item->filePathName)) );
}
if( sub_item->queued && proc->signalled() ) {
sub_item->queued = false;
- sub_item->repaint();
+ sub_item->tqrepaint();
}
}
}
diff --git a/src/replaygainfilelist.h b/src/replaygainfilelist.h
index 2be294d..6cd882c 100755
--- a/src/replaygainfilelist.h
+++ b/src/replaygainfilelist.h
@@ -66,7 +66,7 @@ public:
*/
virtual ~ReplayGainFileListItem();
- virtual void paintCell( TQPainter* p, const TQColorGroup& cg, int column, int width, int alignment );
+ virtual void paintCell( TQPainter* p, const TQColorGroup& cg, int column, int width, int tqalignment );
int compare( TQListViewItem* item, int column, bool ascending ) const;
@@ -149,7 +149,7 @@ private:
int listDir( const TQString& directory, TQStringList filter, bool recursive = true, bool fast = false, int count = 0 );
/** A progressbar, that is shown, when a directory is added recursive */
- KProgress* pScanStatus;
+ KProgress* pScantqStatus;
TagEngine* tagEngine;
Config* config;
diff --git a/src/replaygainscanner.cpp b/src/replaygainscanner.cpp
index 8fdf487..2bafc9e 100755
--- a/src/replaygainscanner.cpp
+++ b/src/replaygainscanner.cpp
@@ -5,7 +5,7 @@
#include "config.h"
#include "dirdialog.h"
-#include <layout.h>
+#include <tqlayout.h>
#include <tqstringlist.h>
#include <tqlabel.h>
#include <tqcheckbox.h>
diff --git a/src/soundkonverter.cpp b/src/soundkonverter.cpp
index a3b689e..3efcfdc 100755
--- a/src/soundkonverter.cpp
+++ b/src/soundkonverter.cpp
@@ -36,7 +36,7 @@
#include <kprocess.h>
#include <ksystemtray.h>
-#include <layout.h>
+#include <tqlayout.h>
#include <tqprogressbar.h>
#include <tqfont.h>
#include <tqhbox.h>
@@ -222,7 +222,7 @@ soundKonverter::soundKonverter()
// convert, TQT_SLOT(priorityChanged(int))
// );
- // add a horizontal box layout for the add combobutton to the grid
+ // add a horizontal box tqlayout for the add combobutton to the grid
TQHBoxLayout *addBox = new TQHBoxLayout( -1, "addBox" );
gridLayout->addLayout( addBox, 2, 0 );
diff --git a/src/cdopener.cpp b/src/cdopener.cpp
index 77cbe04..12779be 100755
--- a/src/cdopener.cpp
+++ b/src/cdopener.cpp
@@ -17,7 +17,7 @@
#include <kfiledialog.h>
#include <kmessagebox.h>
-#include <layout.h>
+#include <tqlayout.h>
#include <tqlabel.h>
#include <tqgroupbox.h>
#include <tqdatetime.h>
@@ -59,18 +59,18 @@ CDOpener::CDOpener( Config* _config, CDManager* _cdManager, TagEngine* _tagEngin
connect( cArtist, TQT_SIGNAL(textChanged(const TQString&)),
this, TQT_SLOT(artistChanged(const TQString&))
);
// add a horizontal box layout for the composer
TQHBoxLayout* artistBox = new TQHBoxLayout( -1, "artistBox" );
topGridLayout->addLayout( artistBox, 0, 3 );
// and fill it up
TQLabel* lComposerLabel = new TQLabel( i18n("Composer:"), this, "lComposerLabel" );
- lComposerLabel->setAlignment( TQt::AlignRight | TQt::AlignVCenter );
+ lComposerLabel->tqsetAlignment( TQt::AlignRight | TQt::AlignVCenter );
topGridLayout->addWidget( lComposerLabel, 0, 2 );
cComposer = new KComboBox( true, this, "cComposer" );
artistBox->addWidget( cComposer );
cComposer->insertItem( i18n("Various Composer") );
cComposer->setCurrentText( "" );
- //cComposer->setSizePolicy( TQSizePolicy::Maximum );
+ //cComposer->tqsetSizePolicy( TQSizePolicy::Maximum );
connect( cComposer, TQT_SIGNAL(textChanged(const TQString&)),
this, TQT_SLOT(composerChanged(const TQString&))
);
@@ -84,18 +84,18 @@ CDOpener::CDOpener( Config* _config, CDManager* _cdManager, TagEngine* _tagEngin
topGridLayout->addWidget( lAlbumLabel, 1, 0 );
lAlbum = new KLineEdit( this, "lAlbum" );
topGridLayout->addWidget( lAlbum, 1, 1 );
// add a horizontal box layout for the disc number, year and genre
TQHBoxLayout* albumBox = new TQHBoxLayout( -1, "albumBox" );
topGridLayout->addLayout( albumBox, 1, 3 );
// and fill it up
TQLabel* lDiscLabel = new TQLabel( i18n("Disc No.:"), this, "lDiscLabel" );
- lDiscLabel->setAlignment( TQt::AlignRight | TQt::AlignVCenter );
+ lDiscLabel->tqsetAlignment( TQt::AlignRight | TQt::AlignVCenter );
topGridLayout->addWidget( lDiscLabel, 1, 2 );
iDisc = new KIntSpinBox( 1, 99, 1, 1, 10, this, "iDisc" );
albumBox->addWidget( iDisc );
TQLabel* lYearLabel = new TQLabel( i18n("Year:"), this, "lYearLabel" );
albumBox->addWidget( lYearLabel );
- iYear = new KIntSpinBox( 0, 99999, 1, TQDate::currentDate().year(), 10, this, "iYear" );
+ iYear = new KIntSpinBox( 0, 99999, 1, TQDate::tqcurrentDate().year(), 10, this, "iYear" );
albumBox->addWidget( iYear );
TQLabel* lGenreLabel = new TQLabel( i18n("Genre:"), this, "lGenreLabel" );
albumBox->addWidget( lGenreLabel );
@@ -131,9 +131,9 @@ CDOpener::CDOpener( Config* _config, CDManager* _cdManager, TagEngine* _tagEngin
tagGroupBox = new TQGroupBox( i18n("No track selected"), this, "tagGroupBox" );
gridLayout->addWidget( tagGroupBox, 2, 0 );
tagGroupBox->setColumnLayout( 0, Qt::Vertical );
- tagGroupBox->layout()->setSpacing( 6 );
- tagGroupBox->layout()->setMargin( 6 );
- TQGridLayout* tagGridLayout = new TQGridLayout( tagGroupBox->layout(), 1, 1, -1, "tagGridLayout" );
+ tagGroupBox->tqlayout()->setSpacing( 6 );
+ tagGroupBox->tqlayout()->setMargin( 6 );
+ TQGridLayout* tagGridLayout = new TQGridLayout( tagGroupBox->tqlayout(), 1, 1, -1, "tagGridLayout" );
// add the up and down buttons
pTrackUp = new KPushButton( " ", tagGroupBox, "pTrackUp" );
@@ -152,7 +152,7 @@ CDOpener::CDOpener( Config* _config, CDManager* _cdManager, TagEngine* _tagEngin
tagGridLayout->addWidget( pTrackDown, 1, 0 );
// add the inputs
// add a horizontal box layout for the title
TQHBoxLayout* trackTitleBox = new TQHBoxLayout( -1, "trackTitleBox" );
tagGridLayout->addLayout( trackTitleBox, 0, 2 );
// and fill it up
@@ -165,13 +165,13 @@ CDOpener::CDOpener( Config* _config, CDManager* _cdManager, TagEngine* _tagEngin
);
pTrackTitleEdit = new KPushButton( " ", tagGroupBox, "pTrackTitleEdit" );
pTrackTitleEdit->setPixmap( iconLoader->loadIcon("kwrite",KIcon::Small) );
- pTrackTitleEdit->setFixedSize( lTrackTitle->sizeHint().height(), lTrackTitle->sizeHint().height() );
+ pTrackTitleEdit->setFixedSize( lTrackTitle->tqsizeHint().height(), lTrackTitle->tqsizeHint().height() );
pTrackTitleEdit->hide();
trackTitleBox->addWidget( pTrackTitleEdit );
connect( pTrackTitleEdit, TQT_SIGNAL(clicked()),
this, TQT_SLOT(editTrackTitleClicked())
);
// add a horizontal box layout for the composer
TQHBoxLayout* trackArtistBox = new TQHBoxLayout( -1, "trackArtistBox" );
tagGridLayout->addLayout( trackArtistBox, 1, 2 );
// and fill it up
@@ -184,7 +184,7 @@ CDOpener::CDOpener( Config* _config, CDManager* _cdManager, TagEngine* _tagEngin
);
pTrackArtistEdit = new KPushButton( " ", tagGroupBox, "pTrackArtistEdit" );
pTrackArtistEdit->setPixmap( iconLoader->loadIcon("kwrite",KIcon::Small) );
- pTrackArtistEdit->setFixedSize( lTrackArtist->sizeHint().height(), lTrackArtist->sizeHint().height() );
+ pTrackArtistEdit->setFixedSize( lTrackArtist->tqsizeHint().height(), lTrackArtist->tqsizeHint().height() );
pTrackArtistEdit->hide();
trackArtistBox->addWidget( pTrackArtistEdit );
connect( pTrackArtistEdit, TQT_SIGNAL(clicked()),
@@ -199,13 +199,13 @@ CDOpener::CDOpener( Config* _config, CDManager* _cdManager, TagEngine* _tagEngin
);
pTrackComposerEdit = new KPushButton( " ", tagGroupBox, "pTrackComposerEdit" );
pTrackComposerEdit->setPixmap( iconLoader->loadIcon("kwrite",KIcon::Small) );
- pTrackComposerEdit->setFixedSize( lTrackComposer->sizeHint().height(), lTrackComposer->sizeHint().height() );
+ pTrackComposerEdit->setFixedSize( lTrackComposer->tqsizeHint().height(), lTrackComposer->tqsizeHint().height() );
pTrackComposerEdit->hide();
trackArtistBox->addWidget( pTrackComposerEdit );
connect( pTrackComposerEdit, TQT_SIGNAL(clicked()),
this, TQT_SLOT(editTrackComposerClicked())
);
// add a horizontal box layout for the comment
TQHBoxLayout* trackCommentBox = new TQHBoxLayout( -1, "trackCommentBox" );
tagGridLayout->addLayout( trackCommentBox, 2, 2 );
// and fill it up
@@ -219,7 +219,7 @@ CDOpener::CDOpener( Config* _config, CDManager* _cdManager, TagEngine* _tagEngin
);
pTrackCommentEdit = new KPushButton( " ", tagGroupBox, "pTrackCommentEdit" );
pTrackCommentEdit->setPixmap( iconLoader->loadIcon("kwrite",KIcon::Small) );
- pTrackCommentEdit->setFixedSize( lTrackTitle->sizeHint().height(), lTrackTitle->sizeHint().height() );
+ pTrackCommentEdit->setFixedSize( lTrackTitle->tqsizeHint().height(), lTrackTitle->tqsizeHint().height() );
pTrackCommentEdit->hide();
trackCommentBox->addWidget( pTrackCommentEdit );
connect( pTrackCommentEdit, TQT_SIGNAL(clicked()),
@@ -234,7 +234,7 @@ CDOpener::CDOpener( Config* _config, CDManager* _cdManager, TagEngine* _tagEngin
gridLayout->addWidget( lineFrame, 3, 0 );
gridLayout->setRowSpacing( 3, 16 );
// add a horizontal box layout for the control elements
TQHBoxLayout* controlBox = new TQHBoxLayout( -1, "controlBox" );
gridLayout->addLayout( controlBox, 4, 0 );
@@ -59,18 +59,18 @@ CDOpener::CDOpener( Config* _config, CDManager* _cdManager, TagEngine* _tagEngin
this, TQT_SLOT(artistChanged(const TQString&))
);
- // add a horizontal box layout for the composer
+ // add a horizontal box tqlayout for the composer
TQHBoxLayout* artistBox = new TQHBoxLayout( -1, "artistBox" );
topGridLayout->addLayout( artistBox, 0, 3 );
@@ -84,18 +84,18 @@ CDOpener::CDOpener( Config* _config, CDManager* _cdManager, TagEngine* _tagEngin
lAlbum = new KLineEdit( this, "lAlbum" );
topGridLayout->addWidget( lAlbum, 1, 1 );
- // add a horizontal box layout for the disc number, year and genre
+ // add a horizontal box tqlayout for the disc number, year and genre
TQHBoxLayout* albumBox = new TQHBoxLayout( -1, "albumBox" );
topGridLayout->addLayout( albumBox, 1, 3 );
@@ -152,7 +152,7 @@ CDOpener::CDOpener( Config* _config, CDManager* _cdManager, TagEngine* _tagEngin
tagGridLayout->addWidget( pTrackDown, 1, 0 );
// add the inputs
- // add a horizontal box layout for the title
+ // add a horizontal box tqlayout for the title
TQHBoxLayout* trackTitleBox = new TQHBoxLayout( -1, "trackTitleBox" );
tagGridLayout->addLayout( trackTitleBox, 0, 2 );
@@ -165,13 +165,13 @@ CDOpener::CDOpener( Config* _config, CDManager* _cdManager, TagEngine* _tagEngin
this, TQT_SLOT(editTrackTitleClicked())
);
- // add a horizontal box layout for the composer
+ // add a horizontal box tqlayout for the composer
TQHBoxLayout* trackArtistBox = new TQHBoxLayout( -1, "trackArtistBox" );
tagGridLayout->addLayout( trackArtistBox, 1, 2 );
@@ -199,13 +199,13 @@ CDOpener::CDOpener( Config* _config, CDManager* _cdManager, TagEngine* _tagEngin
this, TQT_SLOT(editTrackComposerClicked())
);
- // add a horizontal box layout for the comment
+ // add a horizontal box tqlayout for the comment
TQHBoxLayout* trackCommentBox = new TQHBoxLayout( -1, "trackCommentBox" );
tagGridLayout->addLayout( trackCommentBox, 2, 2 );
@@ -234,7 +234,7 @@ CDOpener::CDOpener( Config* _config, CDManager* _cdManager, TagEngine* _tagEngin
gridLayout->addWidget( lineFrame, 3, 0 );
gridLayout->setRowSpacing( 3, 16 );
- // add a horizontal box layout for the control elements
+ // add a horizontal box tqlayout for the control elements
TQHBoxLayout* controlBox = new TQHBoxLayout( -1, "controlBox" );
gridLayout->addLayout( controlBox, 4, 0 );